pub struct ComWorker<C: ServerConnector + 'static> {
pub sender: Sender<ComRequest>,
pub handle: Option<JoinHandle<()>>,
/* private fields */
}Expand description
Dedicated background worker thread manager handling COM MTA apartment thread affinity.
Dispatches requests received over an mpsc channel to Windows COM interfaces while maintaining
a persistent connection pool and transparently evicting stale connection handles on RPC errors.
Fields
sender: Sender<ComRequest>Channel sender for dispatching requests to the worker loop.
handle: Option<JoinHandle<()>>Thread join handle for clean worker thread teardown.
Implementations
Sourceimpl<C: ServerConnector + 'static> ComWorker<C>
impl<C: ServerConnector + 'static> ComWorker<C>