pub enum BrowseNodeKind {
Branch,
Item,
BranchAndItem,
}Expand description
Kinds of nodes returned by a native browse.
Variants
Branch
A branch that can have children but is not itself an item.
Item
An item that has no browsable children.
BranchAndItem
A node that is both an item and a branch.
Implementations