#[repr(transparent)]pub struct GroupHandle(pub u32);Expand description
Opaque handle for an OPC group.
This wrapper type enhances type safety when interacting with OPC COM interfaces, preventing accidental mixing of group and item handles.
Examples
use opc_da_client::GroupHandle;
let handle = GroupHandle(123u32);
assert_eq!(handle.0, 123u32);Tuple Fields
0: u32Trait Implementations
Sourceimpl Clone for GroupHandle
impl Clone for GroupHandle
Sourcefn clone(&self) -> GroupHandle
fn clone(&self) -> GroupHandle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for GroupHandle
Sourceimpl Debug for GroupHandle
impl Debug for GroupHandle
Sourceimpl Default for GroupHandle
impl Default for GroupHandle
Sourcefn default() -> GroupHandle
fn default() -> GroupHandle
Returns the “default value” for a type. Read more
impl Eq for GroupHandle
Sourceimpl Hash for GroupHandle
impl Hash for GroupHandle
Sourceimpl PartialEq for GroupHandle
impl PartialEq for GroupHandle
impl StructuralPartialEq for GroupHandle