pub struct InventoryPacing {
pub min_interval: Duration,
}Expand description
Dynamic delay enforced before each bounded native inventory operation.
Fields
min_interval: DurationMinimum interval between the starts of bounded native operations.