pub struct MockOpcProvider { /* private fields */ }Expand description
Async trait for OPC DA operations.
This is the stable public API. Backend implementations provide the actual COM/DCOM interaction.
Implementations
Sourceimpl MockOpcProvider
impl MockOpcProvider
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockOpcProvider
impl MockOpcProvider
Sourcepub fn expect_list_servers(&mut self) -> &mut Expectation
pub fn expect_list_servers(&mut self) -> &mut Expectation
Create an Expectation for mocking the list_servers method
Create an Expectation for mocking the browse_tags method
Sourcepub fn expect_browse_capabilities(&mut self) -> &mut Expectation
pub fn expect_browse_capabilities(&mut self) -> &mut Expectation
Create an Expectation for mocking the browse_capabilities method
Sourcepub fn expect_open_browse_session(&mut self) -> &mut Expectation
pub fn expect_open_browse_session(&mut self) -> &mut Expectation
Create an Expectation for mocking the open_browse_session method
Sourcepub fn expect_browse_page(&mut self) -> &mut Expectation
pub fn expect_browse_page(&mut self) -> &mut Expectation
Create an Expectation for mocking the browse_page method
Sourcepub fn expect_close_browse_session(&mut self) -> &mut Expectation
pub fn expect_close_browse_session(&mut self) -> &mut Expectation
Create an Expectation for mocking the close_browse_session method
Sourcepub fn expect_start_inventory(&mut self) -> &mut Expectation
pub fn expect_start_inventory(&mut self) -> &mut Expectation
Create an Expectation for mocking the start_inventory method
Sourcepub fn expect_read_tag_values(&mut self) -> &mut Expectation
pub fn expect_read_tag_values(&mut self) -> &mut Expectation
Create an Expectation for mocking the read_tag_values method
Sourcepub fn expect_read_tag_values_for_display(&mut self) -> &mut Expectation
pub fn expect_read_tag_values_for_display(&mut self) -> &mut Expectation
Create an Expectation for mocking the read_tag_values_for_display method
Sourcepub fn expect_write_tag_value(&mut self) -> &mut Expectation
pub fn expect_write_tag_value(&mut self) -> &mut Expectation
Create an Expectation for mocking the write_tag_value method